<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="设备编号" prop="deviceId">
        <el-input
          v-model="queryParams.deviceId"
          placeholder="请输入设备编号"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="设备名称" prop="deviceName">
        <el-input
          v-model="queryParams.deviceName"
          placeholder="请输入设备名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['system:device:add']"
        >新增</el-button>
      </el-col>
    </el-row>

    <el-table v-loading="loading" :data="deviceList" @selection-change="handleSelectionChange">
      <el-table-column label="设备编号" align="center" prop="deviceId" />
      <el-table-column label="设备名称" align="center" prop="deviceName" />
      <el-table-column label="设备舰船类型" align="center" prop="shipTypeName" />
      <!-- <el-table-column label="设备概述" align="center" prop="deviceOverview" /> -->
      <!-- <el-table-column label="设备模型文件" align="center" prop="deviceModel" /> -->
      <!-- <el-table-column label="设备参数" align="center" prop="deviceParameters" /> -->
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:device:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:device:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>
    
    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改舰艇设备对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="设备类型" prop="deviceId">
          <el-input v-model="form.deviceId" placeholder="请输入设备编号" />
        </el-form-item>
        <el-form-item label="设备名称" prop="deviceName">
          <el-input v-model="form.deviceName" placeholder="请输入设备名称" />
        </el-form-item>
        <el-form-item label="舰船类型" prop="shipTypeId">
          <el-select v-model="form.shipTypeId" placeholder="请选择所属舰船类型">
            <el-option
              v-for="item in shipTypeOptions"
              :key="item.id"
              :label="item.typeName+'-'+item.shipDesign"
              :value="item.id"
            ></el-option>
          </el-select>
        </el-form-item>
        <!-- <el-form-item label="设备概述" prop="deviceOverview">
          <el-input v-model="form.deviceOverview" type="textarea" placeholder="请输入设备概述" />
        </el-form-item>
        <el-form-item label="设备参数" prop="deviceParameters">
          <el-input v-model="form.deviceParameters" type="textarea" placeholder="请输入设备参数" />
        </el-form-item> -->
        <el-form-item label="target" prop="target">
          <el-input v-model="form.target" placeholder="请输入设备target" />
        </el-form-item>
        <el-form-item label="position" prop="position">
          <el-input v-model="form.position" placeholder="请输入设备position" />
        </el-form-item>
        <el-form-item label="模型字段" prop="fieldName">
          <el-input v-model="form.fieldName" placeholder="请输入设备模型字段" />
        </el-form-item>
        <!-- <el-form-item label="模型文件" prop="deviceModel">
          <el-upload
            class="upload-demo"
            :action="uploadFileUrl"
            :on-remove="handleRemove"
            :on-success="handleAvatarSuccess"
            :file-list="fileList"
          >
            <el-button size="small" type="primary">点击上传</el-button>
          </el-upload>
        </el-form-item> -->

      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listDevice, getDevice, delDevice, addDevice, updateDevice } from "@/api/manage/device";
import { listAlldpShipTypeList} from "@/api/manage/shipType";

const baseUrl = process.env.VUE_APP_BASE_API

export default {
  name: "Device",
  data() {
    return {
      // 遮罩层
      loading: true,
      fileList: [],
      imageUrl: "",
      // 选中数组
      ids: [],
      shipTypeOptions:[],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 舰艇设备表格数据
      deviceList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        deviceId: null,
        deviceName: null,
        deviceShipId: null,
        deviceOverview: null,
        deviceModel: null,
        deviceParameters: null,
        updateTime: null,
        updateUser: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        deviceId: [
          { required: true, message: "设备编号不能为空", trigger: "blur" }
        ],
      },
      uploadFileUrl: baseUrl+ "common/upload",
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询舰艇设备列表 */
    getList() {
      this.loading = true;
      listDevice(this.queryParams).then(response => {
        this.deviceList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        deviceId: null,
        deviceName: null,
        deviceShipId: null,
        deviceOverview: null,
        deviceModel: null,
        deviceParameters: null,
        updateTime: null,
        updateUser: null,
        ID: null
      };
      this.resetForm("form");
      this.fileList = [];
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.ID)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.imageUrl = "";
      listAlldpShipTypeList().then(response=>{
        this.shipTypeOptions = response.data;
      })
      this.open = true;
      this.title = "添加舰艇设备";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      listAlldpShipTypeList().then(response=>{
        this.shipTypeOptions = response.data;
      })
      const id = row.id
      getDevice(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改舰艇设备";
        var fileListStr = response.data.deviceModel;
        this.imageUrl = fileListStr == null ? "" : fileListStr;
        if (fileListStr) {
          if (fileListStr.endsWith(",")) {
            this.imageUrl = fileListStr;
            fileListStr = fileListStr.slice(0, -1); // 删除最后一个字符（逗号）
          }else{
            this.imageUrl = fileListStr + ',';
          }
          const arr = fileListStr.split(","); // 将文件路径字符串拆分成数组
          this.fileList = arr.map((item, index) => ({
            name: item.split("/").pop(), // 提取文件名
            url: baseUrl.slice(0, -1) + item, // 拼接完整的文件 URL
            status: "success", // 上传状态设置为成功
            uid: `uid-${index}`, // 使用唯一的 uid
          }));
        }else{
          this.imageUrl = '';
        }
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateDevice(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addDevice(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const id = row.id;
      this.$modal.confirm('是否确认删除舰艇设备编号为"' + row.deviceId+ '"的数据项？').then(function() {
        return delDevice(id);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    handleRemove(file, fileList) {
      // var fileUrl = this.imageUrl.replace(file.response.fileName + ",", "");
      // this.form.deviceModel = fileUrl;
      // console.log(this.form.deviceModel);
      // console.log(baseUrl.slice(0, -1))
      const remainingUrls = fileList.map((item) =>
        item.url.replace(baseUrl.slice(0, -1), "")
      );
      this.form.deviceModel = remainingUrls.join(",");
      this.imageUrl = remainingUrls.join(",");
      // console.log(this.form.deviceModel);
    },
    handleAvatarSuccess(res, file) {
      this.imageUrl += res.fileName + ",";
      this.form.deviceModel = this.imageUrl;
      console.log(this.form.deviceModel);
    }
  }
};
</script>
